event_types = [
    "message_new",
    "message_reply",
    "message_edit",
    "message_allow",
    "message_deny",
    "photo_new",
    "photo_comment_new",
    "photo_comment_edit",
    "photo_comment_restore",
    "photo_comment_delete",
    "audio_new",
    "video_new",
    "video_comment_new",
    "video_comment_edit",
    "video_comment_restore",
    "video_comment_delete",
    "wall_post_new",
    "wall_repost",
    "wall_reply_new",
    "wall_reply_edit",
    "wall_reply_restore",
    "wall_reply_delete",
    "board_post_new",
    "board_post_edit",
    "board_post_restore",
    "board_post_delete",
    "market_comment_new",
    "market_comment_edit",
    "market_comment_restore",
    "market_comment_delete",
    "group_leave",
    "group_join",
    "user_block",
    "user_unblock",
    "poll_vote_new",
    "group_officers_edit",
    "group_change_settings",
    "group_change_photo",
    "vkpay_transaction"
]